@@ -179,7 +179,7 @@ class OAuth2Service(Service):
             "grant_type": "refresh_token",
             "refresh_token": token.refresh_token,
             "redirect_uri": "{}/redirect".format(
-                os.getenv("FLASK_HOST_ADDRESS", "http://localhost:8080")
+                os.getenv("RDS_OAUTH_REDIRECT_URI", "http://localhost:8080")
             ),
             "client_id": self.client_id,
             "client_secret": self.client_secret,
